from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import Network

nw_establishment_report_access_block_t = b"v@"
nw_report_resolution_enumerator_t = objc._C_BOOL + b"@QI@@"
nw_report_protocol_enumerator_t = objc._C_BOOL + b"@QQ"
nw_data_transfer_report_collect_block_t = b"v@"


class TestConnectionReport(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_report_resolution_source_query, 1)
        self.assertEqual(Network.nw_report_resolution_source_cache, 2)
        self.assertEqual(Network.nw_report_resolution_source_expired_cache, 3)

        self.assertEqual(Network.nw_data_transfer_report_state_collecting, 1)
        self.assertEqual(Network.nw_data_transfer_report_state_collected, 2)

        self.assertEqual(Network.nw_report_resolution_protocol_unknown, 0)
        self.assertEqual(Network.nw_report_resolution_protocol_udp, 1)
        self.assertEqual(Network.nw_report_resolution_protocol_tcp, 2)
        self.assertEqual(Network.nw_report_resolution_protocol_tls, 3)
        self.assertEqual(Network.nw_report_resolution_protocol_https, 4)

    @min_os_level("10.15")
    def test_contants10_15(self):
        self.assertIsInstance(Network.NW_ALL_PATHS, int)

    @min_os_level("10.15")
    def test_functions10_15(self):
        self.assertArgIsBlock(
            Network.nw_connection_access_establishment_report,
            2,
            nw_establishment_report_access_block_t,
        )

        Network.nw_establishment_report_get_duration_milliseconds
        Network.nw_establishment_report_get_attempt_started_after_milliseconds
        Network.nw_establishment_report_get_previous_attempt_count
        Network.nw_establishment_report_get_used_proxy
        Network.nw_establishment_report_get_proxy_configured

        self.assertResultIsRetained(Network.nw_establishment_report_copy_proxy_endpoint)

        self.assertArgIsBlock(
            Network.nw_establishment_report_enumerate_resolutions,
            1,
            nw_report_resolution_enumerator_t,
        )

        self.assertArgIsBlock(
            Network.nw_establishment_report_enumerate_protocols,
            1,
            nw_report_protocol_enumerator_t,
        )

        self.assertResultIsRetained(
            Network.nw_connection_create_new_data_transfer_report
        )

        Network.nw_data_transfer_report_get_state

        self.assertArgIsBlock(
            Network.nw_data_transfer_report_collect,
            2,
            nw_data_transfer_report_collect_block_t,
        )

        Network.nw_data_transfer_report_get_duration_milliseconds
        Network.nw_data_transfer_report_get_path_count
        Network.nw_data_transfer_report_get_received_ip_packet_count
        Network.nw_data_transfer_report_get_sent_ip_packet_count
        Network.nw_data_transfer_report_get_received_transport_byte_count
        Network.nw_data_transfer_report_get_received_transport_duplicate_byte_count
        Network.nw_data_transfer_report_get_received_transport_out_of_order_byte_count
        Network.nw_data_transfer_report_get_sent_transport_byte_count
        Network.nw_data_transfer_report_get_sent_transport_retransmitted_byte_count
        Network.nw_data_transfer_report_get_transport_smoothed_rtt_milliseconds
        Network.nw_data_transfer_report_get_transport_minimum_rtt_milliseconds
        Network.nw_data_transfer_report_get_transport_rtt_variance
        Network.nw_data_transfer_report_get_received_application_byte_count
        Network.nw_data_transfer_report_get_sent_application_byte_count

        self.assertResultIsRetained(Network.nw_data_transfer_report_copy_path_interface)

    @min_os_level("11.0")
    def test_functions11_0(self):
        Network.nw_resolution_report_get_source
        Network.nw_resolution_report_get_milliseconds
        Network.nw_resolution_report_get_endpoint_count
        self.assertResultIsRetained(
            Network.nw_resolution_report_copy_successful_endpoint
        )
        self.assertResultIsRetained(
            Network.nw_resolution_report_copy_preferred_endpoint
        )
        self.assertResultIsRetained(Network.nw_resolution_report_get_protocol)

        nw_report_resolution_report_enumerator_t = b"B@"

        self.assertArgIsBlock(
            Network.nw_establishment_report_enumerate_resolution_reports,
            1,
            nw_report_resolution_report_enumerator_t,
        )

    @min_os_level("12.0")
    def test_functions12_0(self):
        Network.nw_data_transfer_report_get_path_radio_type



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network

nw_listener_state_changed_handler_t = b"vi@"
nw_listener_new_connection_handler_t = b"v@"
nw_listener_advertised_endpoint_changed_handler_t = b"v@B"


class TestListener(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_listener_state_invalid, 0)
        self.assertEqual(Network.nw_listener_state_waiting, 1)
        self.assertEqual(Network.nw_listener_state_ready, 2)
        self.assertEqual(Network.nw_listener_state_failed, 3)
        self.assertEqual(Network.nw_listener_state_cancelled, 4)

        self.assertEqual(Network.NW_LISTENER_INFINITE_CONNECTION_LIMIT, 0xFFFFFFFF)

    def test_functions(self):
        self.assertResultIsRetained(Network.nw_listener_create_with_port)

        self.assertResultIsRetained(Network.nw_listener_create)

        self.assertResultIsRetained(Network.nw_listener_create_with_connection)

        Network.nw_listener_set_queue

        self.assertArgIsBlock(
            Network.nw_listener_set_state_changed_handler,
            1,
            nw_listener_state_changed_handler_t,
        )

        self.assertArgIsBlock(
            Network.nw_listener_set_new_connection_handler,
            1,
            nw_listener_new_connection_handler_t,
        )

        Network.nw_listener_set_advertise_descriptor

        self.assertArgIsBlock(
            Network.nw_listener_set_advertised_endpoint_changed_handler,
            1,
            nw_listener_advertised_endpoint_changed_handler_t,
        )

        Network.nw_listener_get_port
        Network.nw_listener_start
        Network.nw_listener_cancel

    @min_os_level("10.15")
    def test_functions10_15(self):
        Network.nw_listener_get_new_connection_limit
        Network.nw_listener_set_new_connection_limit

    @min_os_level("12.0")
    def test_functions12_0(self):
        Network.nw_listener_set_new_connection_group_handler



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network


class TestGroupDescriptor(TestCase):
    @min_os_level("11.0")
    def test_functions11_0(self):
        self.assertResultIsRetained(Network.nw_group_descriptor_create_multicast)
        Network.nw_group_descriptor_add_endpoint

        nw_group_descriptor_enumerate_endpoints_block_t = b"B@"

        self.assertArgIsBlock(
            Network.nw_group_descriptor_enumerate_endpoints,
            1,
            nw_group_descriptor_enumerate_endpoints_block_t,
        )

        Network.nw_multicast_group_descriptor_set_specific_source
        Network.nw_multicast_group_descriptor_set_disable_unicast_traffic
        Network.nw_multicast_group_descriptor_get_disable_unicast_traffic

    @min_os_level("12.0")
    def test_functions12_0(self):
        self.assertResultIsRetained(Network.nw_group_descriptor_create_multiplex)



from PyObjCTools.TestSupport import TestCase

import Network


class TestNWObject(TestCase):
    def test_functions(self):
        self.assertFalse(hasattr(Network, "nw_retain"))
        self.assertFalse(hasattr(Network, "nw_release"))



"""
Python mapping for the Network framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import Network._Network as _manual
import objc
from Network import _metadata

sys.modules["Network"] = mod = objc.ObjCLazyModule(
    "Network",
    "com.apple.Network",
    objc.pathForFramework("/System/Library/Frameworks/Network.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (Foundation,),
)


del sys.modules["Network._metadata"]


for nm in dir(_manual):
    if nm.startswith("__"):
        continue
    setattr(mod, nm, getattr(_manual, nm))



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network


class TestIPOptions(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_ip_version_any, 0)
        self.assertEqual(Network.nw_ip_version_4, 4)
        self.assertEqual(Network.nw_ip_version_6, 6)

        self.assertEqual(Network.nw_ip_ecn_flag_non_ect, 0)
        self.assertEqual(Network.nw_ip_ecn_flag_ect_0, 2)
        self.assertEqual(Network.nw_ip_ecn_flag_ect_1, 1)
        self.assertEqual(Network.nw_ip_ecn_flag_ce, 3)

        self.assertEqual(Network.nw_ip_local_address_preference_default, 0)
        self.assertEqual(Network.nw_ip_local_address_preference_temporary, 1)
        self.assertEqual(Network.nw_ip_local_address_preference_stable, 2)

    def test_functions(self):
        Network.nw_ip_options_set_version
        Network.nw_ip_options_set_hop_limit
        Network.nw_ip_options_set_use_minimum_mtu
        Network.nw_ip_options_set_disable_fragmentation

        self.assertResultIsRetained(Network.nw_ip_create_metadata)

        Network.nw_protocol_metadata_is_ip
        Network.nw_ip_metadata_set_ecn_flag
        Network.nw_ip_metadata_get_ecn_flag
        Network.nw_ip_metadata_set_service_class
        Network.nw_ip_metadata_get_service_class
        Network.nw_ip_options_set_calculate_receive_time
        Network.nw_ip_metadata_get_receive_time

    @min_os_level("10.15")
    def test_funtions10_15(self):
        Network.nw_ip_options_set_local_address_preference

    @min_os_level("11.0")
    def test_funtions11_0(self):
        Network.nw_ip_options_set_disable_multicast_loopback



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network

nw_framer_message_dispose_value_t = b"v^v"
nw_framer_start_handler_t = b"i@"
nw_framer_input_handler_t = b"L@"
nw_framer_output_handler_t = b"v@@LB"
nw_framer_wakeup_handler_t = b"v@"
nw_framer_stop_handler_t = b"B@"
nw_framer_cleanup_handler_t = b"v@"
nw_framer_parse_completion_t = b"Ln^vLB"
nw_framer_block_t = b"v"


class TestFramerOptions(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_framer_start_result_ready, 1)
        self.assertEqual(Network.nw_framer_start_result_will_mark_ready, 2)

        self.assertEqual(Network.NW_FRAMER_CREATE_FLAGS_DEFAULT, 0x00)

        self.assertEqual(Network.NW_FRAMER_WAKEUP_TIME_FOREVER, 0xFFFFFFFFFFFFFFFF)

    @min_os_level("10.15")
    def test_functions10_15(self):
        self.assertResultIsRetained(Network.nw_framer_protocol_create_message)

        Network.nw_protocol_metadata_is_framer_message

        self.assertResultIsRetained(Network.nw_framer_message_create)

        self.assertArgIsIn(Network.nw_framer_message_set_value, 1)
        self.assertArgIsNullTerminated(Network.nw_framer_message_set_value, 1)
        self.assertArgIsBlock(
            Network.nw_framer_message_set_value, 3, nw_framer_message_dispose_value_t
        )

        self.assertArgIsIn(Network.nw_framer_message_access_value, 1)
        self.assertArgIsNullTerminated(Network.nw_framer_message_access_value, 1)
        self.assertArgIsBlock(Network.nw_framer_message_access_value, 2, b"B^v")

        self.assertArgIsIn(Network.nw_framer_message_set_object_value, 1)
        self.assertArgIsNullTerminated(Network.nw_framer_message_set_object_value, 1)

        self.assertResultIsRetained(Network.nw_framer_message_copy_object_value)

        self.assertResultIsRetained(Network.nw_framer_create_definition)
        self.assertArgIsBlock(
            Network.nw_framer_create_definition, 2, nw_framer_start_handler_t
        )

        self.assertResultIsRetained(Network.nw_framer_create_options)

        self.assertArgIsBlock(
            Network.nw_framer_set_input_handler, 1, nw_framer_input_handler_t
        )

        self.assertArgIsBlock(
            Network.nw_framer_set_output_handler, 1, nw_framer_output_handler_t
        )

        self.assertArgIsBlock(
            Network.nw_framer_set_wakeup_handler, 1, nw_framer_wakeup_handler_t
        )

        self.assertArgIsBlock(
            Network.nw_framer_set_stop_handler, 1, nw_framer_stop_handler_t
        )

        self.assertArgIsBlock(
            Network.nw_framer_set_cleanup_handler, 1, nw_framer_cleanup_handler_t
        )

        Network.nw_framer_mark_ready
        Network.nw_framer_prepend_application_protocol
        Network.nw_framer_mark_failed_with_error

        # self.fail("nw_framer_parse_input: buffer lives longer than call")
        self.assertArgIsIn(Network.nw_framer_parse_input, 3)
        self.assertArgSizeInArg(Network.nw_framer_parse_input, 3, 2)
        self.assertArgIsBlock(
            Network.nw_framer_parse_input, 4, nw_framer_parse_completion_t
        )

        self.assertArgHasType(Network.nw_framer_deliver_input, 1, b"n^v")
        self.assertArgSizeInArg(Network.nw_framer_deliver_input, 1, 2)

        Network.nw_framer_deliver_input_no_copy
        Network.nw_framer_pass_through_input

        # self.fail("nw_framer_parse_output: buffer lives longer than call")
        self.assertArgIsOut(Network.nw_framer_parse_output, 3)
        self.assertArgSizeInArg(Network.nw_framer_parse_output, 3, 2)
        self.assertArgIsBlock(
            Network.nw_framer_parse_output, 4, nw_framer_parse_completion_t
        )

        self.assertArgHasType(Network.nw_framer_write_output, 1, b"n^v")
        self.assertArgSizeInArg(Network.nw_framer_write_output, 1, 2)

        Network.nw_framer_write_output_data
        Network.nw_framer_write_output_no_copy
        Network.nw_framer_pass_through_output
        Network.nw_framer_schedule_wakeup

        self.assertArgIsBlock(Network.nw_framer_async, 1, nw_framer_block_t)

        self.assertResultIsRetained(Network.nw_framer_copy_remote_endpoint)
        self.assertResultIsRetained(Network.nw_framer_copy_local_endpoint)
        self.assertResultIsRetained(Network.nw_framer_copy_parameters)

    @min_os_level("12.3")
    def test_functions12_3(self):
        self.assertArgIsIn(Network.nw_framer_options_set_object_value, 1)
        self.assertArgIsNullTerminated(Network.nw_framer_options_set_object_value, 1)

        self.assertResultIsRetained(Network.nw_framer_options_copy_object_value)
        self.assertArgIsIn(Network.nw_framer_options_copy_object_value, 1)
        self.assertArgIsNullTerminated(Network.nw_framer_options_copy_object_value, 1)

        self.assertResultIsRetained(Network.nw_framer_copy_options)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import Network

nw_browse_result_enumerate_interface_t = objc._C_BOOL + objc._C_ID


class TestBrowseResult(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_browse_result_change_invalid, 0x00)
        self.assertEqual(Network.nw_browse_result_change_identical, 0x01)
        self.assertEqual(Network.nw_browse_result_change_result_added, 0x02)
        self.assertEqual(Network.nw_browse_result_change_result_removed, 0x04)
        self.assertEqual(Network.nw_browse_result_change_interface_added, 0x08)
        self.assertEqual(Network.nw_browse_result_change_interface_removed, 0x10)
        self.assertEqual(Network.nw_browse_result_change_txt_record_changed, 0x20)

    @min_os_level("10.15")
    def test_functions10_15(self):
        self.assertResultIsRetained(Network.nw_browse_result_copy_endpoint)

        Network.nw_browse_result_get_changes
        Network.nw_browse_result_get_interfaces_count

        self.assertResultIsRetained(Network.nw_browse_result_copy_txt_record_object)

        self.assertArgIsBlock(
            Network.nw_browse_result_enumerate_interfaces,
            1,
            nw_browse_result_enumerate_interface_t,
        )



from PyObjCTools.TestSupport import TestCase
import objc

import Network


class TestConnection(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_connection_state_invalid, 0)
        self.assertEqual(Network.nw_connection_state_waiting, 1)
        self.assertEqual(Network.nw_connection_state_preparing, 2)
        self.assertEqual(Network.nw_connection_state_ready, 3)
        self.assertEqual(Network.nw_connection_state_failed, 4)
        self.assertEqual(Network.nw_connection_state_cancelled, 5)

        self.assertIsInstance(
            Network.NW_CONNECTION_SEND_IDEMPOTENT_CONTENT, objc.objc_object
        )
        self.assertIsInstance(
            Network.NW_CONNECTION_DEFAULT_MESSAGE_CONTEXT, objc.objc_object
        )
        self.assertIsInstance(
            Network.NW_CONNECTION_FINAL_MESSAGE_CONTEXT, objc.objc_object
        )
        self.assertIsInstance(
            Network.NW_CONNECTION_DEFAULT_STREAM_CONTEXT, objc.objc_object
        )

    def test_functions(self):
        self.assertResultHasType(Network.nw_connection_create, objc._C_ID)
        self.assertResultIsRetained(Network.nw_connection_create)
        self.assertArgHasType(Network.nw_connection_create, 0, objc._C_ID)
        self.assertArgHasType(Network.nw_connection_create, 1, objc._C_ID)

        self.assertResultHasType(Network.nw_connection_copy_endpoint, objc._C_ID)
        self.assertResultIsRetained(Network.nw_connection_copy_endpoint)
        self.assertArgHasType(Network.nw_connection_copy_endpoint, 0, objc._C_ID)

        self.assertResultHasType(Network.nw_connection_copy_parameters, objc._C_ID)
        self.assertResultIsRetained(Network.nw_connection_copy_parameters)
        self.assertArgHasType(Network.nw_connection_copy_parameters, 0, objc._C_ID)

        self.assertArgHasType(
            Network.nw_connection_set_state_changed_handler, 0, objc._C_ID
        )
        self.assertArgIsBlock(
            Network.nw_connection_set_state_changed_handler, 1, b"vi@"
        )

        self.assertArgHasType(
            Network.nw_connection_set_viability_changed_handler, 0, objc._C_ID
        )
        self.assertArgIsBlock(
            Network.nw_connection_set_viability_changed_handler, 1, b"vB"
        )

        self.assertArgHasType(
            Network.nw_connection_set_better_path_available_handler, 0, objc._C_ID
        )
        self.assertArgIsBlock(
            Network.nw_connection_set_better_path_available_handler, 1, b"vB"
        )

        self.assertArgHasType(
            Network.nw_connection_set_path_changed_handler, 0, objc._C_ID
        )
        self.assertArgIsBlock(Network.nw_connection_set_path_changed_handler, 1, b"v@")

        self.assertArgHasType(Network.nw_connection_set_queue, 0, objc._C_ID)
        self.assertArgHasType(Network.nw_connection_set_queue, 1, objc._C_ID)

        self.assertArgHasType(Network.nw_connection_start, 0, objc._C_ID)

        self.assertArgHasType(Network.nw_connection_restart, 0, objc._C_ID)

        self.assertArgHasType(Network.nw_connection_cancel, 0, objc._C_ID)

        self.assertArgHasType(Network.nw_connection_force_cancel, 0, objc._C_ID)

        self.assertArgHasType(
            Network.nw_connection_cancel_current_endpoint, 0, objc._C_ID
        )

        self.assertArgHasType(Network.nw_connection_receive, 0, objc._C_ID)
        self.assertArgIsBlock(Network.nw_connection_receive, 3, b"v@@B@")

        self.assertArgHasType(Network.nw_connection_receive_message, 0, objc._C_ID)
        self.assertArgIsBlock(Network.nw_connection_receive_message, 1, b"v@@B@")

        self.assertArgIsBlock(Network.nw_connection_send, 4, b"v@")
        self.assertArgIsBlock(Network.nw_connection_batch, 1, b"v")

        # XXX: "the caller must call free", therefore need manual wrapper
        Network.nw_connection_copy_description

        self.assertResultIsRetained(Network.nw_connection_copy_current_path)
        self.assertResultIsRetained(Network.nw_connection_copy_protocol_metadata)

        Network.nw_connection_get_maximum_datagram_size



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import Network


class TestPrivacyContext(TestCase):
    @min_os_level("11.0")
    def test_constants11_0(self):
        self.assertIsInstance(Network.NW_DEFAULT_PRIVACY_CONTEXT, objc.objc_object)

    @min_os_level("11.0")
    def test_functions11_0(self):
        self.assertResultIsRetained(Network.nw_privacy_context_create)
        self.assertArgIsIn(Network.nw_privacy_context_create, 0)
        self.assertArgIsNullTerminated(Network.nw_privacy_context_create, 0)

        Network.nw_privacy_context_flush_cache
        Network.nw_privacy_context_disable_logging
        Network.nw_privacy_context_require_encrypted_name_resolution



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network

nw_path_enumerate_interfaces_block_t = b"B@"
nw_path_enumerate_gateways_block_t = b"B@"


class TestPath(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_path_status_invalid, 0)
        self.assertEqual(Network.nw_path_status_satisfied, 1)
        self.assertEqual(Network.nw_path_status_unsatisfied, 2)
        self.assertEqual(Network.nw_path_status_satisfiable, 3)

        self.assertEqual(Network.nw_path_unsatisfied_reason_not_available, 0)
        self.assertEqual(Network.nw_path_unsatisfied_reason_cellular_denied, 1)
        self.assertEqual(Network.nw_path_unsatisfied_reason_wifi_denied, 2)
        self.assertEqual(Network.nw_path_unsatisfied_reason_local_network_denied, 3)

    def test_functions(self):
        Network.nw_path_get_status

        self.assertArgIsBlock(
            Network.nw_path_enumerate_interfaces,
            1,
            nw_path_enumerate_interfaces_block_t,
        )

        Network.nw_path_is_equal
        Network.nw_path_is_expensive
        Network.nw_path_has_ipv4
        Network.nw_path_has_ipv6
        Network.nw_path_has_dns
        Network.nw_path_uses_interface_type

        self.assertResultIsRetained(Network.nw_path_copy_effective_local_endpoint)

        self.assertResultIsRetained(Network.nw_path_copy_effective_remote_endpoint)

    @min_os_level("10.15")
    def test_functions10_15(self):
        Network.nw_path_is_constrained

        self.assertArgIsBlock(
            Network.nw_path_enumerate_gateways, 1, nw_path_enumerate_gateways_block_t
        )

    @min_os_level("11.0")
    def test_functions11_0(self):
        Network.nw_path_get_unsatisfied_reason



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network


class TestInterface(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_endpoint_type_invalid, 0)
        self.assertEqual(Network.nw_endpoint_type_address, 1)
        self.assertEqual(Network.nw_endpoint_type_host, 2)
        self.assertEqual(Network.nw_endpoint_type_bonjour_service, 3)
        self.assertEqual(Network.nw_endpoint_type_url, 4)

    def test_functions(self):
        Network.nw_endpoint_get_type

        self.assertResultIsRetained(Network.nw_endpoint_create_host)
        self.assertArgIsIn(Network.nw_endpoint_create_host, 0)
        self.assertArgIsNullTerminated(Network.nw_endpoint_create_host, 0)
        self.assertArgIsIn(Network.nw_endpoint_create_host, 1)
        self.assertArgIsNullTerminated(Network.nw_endpoint_create_host, 1)

        self.assertResultIsNullTerminated(Network.nw_endpoint_get_hostname)

        self.assertResultIsNullTerminated(Network.nw_endpoint_copy_port_string)

        Network.nw_endpoint_get_port

        self.assertResultIsRetained(Network.nw_endpoint_create_address)
        self.assertArgIsIn(Network.nw_endpoint_create_address, 0)

        self.assertResultIsNullTerminated(Network.nw_endpoint_copy_address_string)

        Network.nw_endpoint_get_address  # XXX Explicit test needed

        self.assertResultIsRetained(Network.nw_endpoint_create_bonjour_service)
        self.assertArgIsIn(Network.nw_endpoint_create_bonjour_service, 0)
        self.assertArgIsNullTerminated(Network.nw_endpoint_create_bonjour_service, 0)
        self.assertArgIsIn(Network.nw_endpoint_create_bonjour_service, 1)
        self.assertArgIsNullTerminated(Network.nw_endpoint_create_bonjour_service, 1)
        self.assertArgIsIn(Network.nw_endpoint_create_bonjour_service, 2)
        self.assertArgIsNullTerminated(Network.nw_endpoint_create_bonjour_service, 2)

        self.assertResultIsNullTerminated(Network.nw_endpoint_get_bonjour_service_name)
        self.assertResultIsNullTerminated(Network.nw_endpoint_get_bonjour_service_type)
        self.assertResultIsNullTerminated(
            Network.nw_endpoint_get_bonjour_service_domain
        )

    @min_os_level("10.15")
    def test_functions10_15(self):
        self.assertResultIsRetained(Network.nw_endpoint_create_url)

        self.assertResultIsNullTerminated(Network.nw_endpoint_get_url)

    @min_os_level("13.0")
    def test_functions13_0(self):
        self.assertResultIsRetained(Network.nw_endpoint_copy_txt_record)

        self.assertResultSizeInArg(Network.nw_endpoint_get_signature, 1)
        self.assertArgIsOut(Network.nw_endpoint_get_signature, 1)



from PyObjCTools.TestSupport import TestCase

import Network


class TestUDPOptions(TestCase):
    def test_functions(self):
        self.assertResultIsRetained(Network.nw_protocol_copy_udp_definition)

        self.assertResultIsRetained(Network.nw_udp_create_options)

        Network.nw_udp_options_set_prefer_no_checksum

        self.assertResultIsRetained(Network.nw_udp_create_metadata)

        Network.nw_protocol_metadata_is_udp



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network
import objc


class TestBrowseDescriptor(TestCase):
    @min_os_level("10.15")
    def test_functions10_15(self):

        self.assertResultIsRetained(Network.nw_browse_descriptor_create_bonjour_service)
        self.assertArgIsIn(Network.nw_browse_descriptor_create_bonjour_service, 0)
        self.assertArgIsNullTerminated(
            Network.nw_browse_descriptor_create_bonjour_service, 0
        )
        self.assertArgIsIn(Network.nw_browse_descriptor_create_bonjour_service, 1)
        self.assertArgIsNullTerminated(
            Network.nw_browse_descriptor_create_bonjour_service, 1
        )

        self.assertResultIsNullTerminated(
            Network.nw_browse_descriptor_get_bonjour_service_type
        )
        self.assertResultIsNullTerminated(
            Network.nw_browse_descriptor_get_bonjour_service_domain
        )
        Network.nw_browse_descriptor_set_include_txt_record
        Network.nw_browse_descriptor_get_include_txt_record

    @min_os_level("13.0")
    def test_functions13_0(self):

        self.assertResultIsRetained(
            Network.nw_browse_descriptor_create_application_service
        )
        self.assertArgHasType(
            Network.nw_browse_descriptor_create_application_service,
            0,
            b"n^" + objc._C_CHAR_AS_TEXT,
        )
        self.assertArgIsNullTerminated(
            Network.nw_browse_descriptor_create_application_service, 0
        )

        self.assertResultHasType(
            Network.nw_browse_descriptor_get_application_service_name,
            b"^" + objc._C_CHAR_AS_TEXT,
        )
        self.assertResultIsNullTerminated(
            Network.nw_browse_descriptor_get_application_service_name
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import Network

nw_browser_browse_results_changed_handler_t = b"v@@" + objc._C_BOOL
nw_browser_state_changed_handler_t = b"v@@"


class TestBrowser(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_browser_state_invalid, 0)
        self.assertEqual(Network.nw_browser_state_ready, 1)
        self.assertEqual(Network.nw_browser_state_failed, 2)
        self.assertEqual(Network.nw_browser_state_cancelled, 3)
        self.assertEqual(Network.nw_browser_state_waiting, 4)

    @min_os_level("10.15")
    def test_functions10_15(self):
        self.assertResultIsRetained(Network.nw_browser_create)

        Network.nw_browser_set_queue

        self.assertArgIsBlock(
            Network.nw_browser_set_browse_results_changed_handler,
            1,
            nw_browser_browse_results_changed_handler_t,
        )
        self.assertArgIsBlock(
            Network.nw_browser_set_state_changed_handler,
            1,
            nw_browser_state_changed_handler_t,
        )

        Network.nw_browser_start
        Network.nw_browser_cancel

        self.assertResultIsRetained(Network.nw_browser_copy_parameters)
        self.assertResultIsRetained(Network.nw_browser_copy_browse_descriptor)



from PyObjCTools.TestSupport import TestCase

import Network


class TestProtocolOptions(TestCase):
    def test_functions(self):
        Network.nw_protocol_definition_is_equal

        self.assertResultIsRetained(Network.nw_protocol_options_copy_definition)

        self.assertResultIsRetained(Network.nw_protocol_metadata_copy_definition)



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network


class TestResolverConfig(TestCase):
    @min_os_level("11.0")
    def test_functions11_0(self):
        self.assertResultIsRetained(Network.nw_resolver_config_create_https)
        self.assertResultIsRetained(Network.nw_resolver_config_create_tls)

        Network.nw_resolver_config_add_server_address



# This file is generated by objective.metadata
#
# Last update: Thu Jul  7 21:54:24 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$_nw_connection_send_idempotent_content@@?$_nw_content_context_default_message$_nw_content_context_default_stream$_nw_content_context_final_send$_nw_data_transfer_report_all_paths@I$_nw_parameters_configure_protocol_default_configuration@@?$_nw_parameters_configure_protocol_disable@@?$_nw_privacy_context_default_context$kNWErrorDomainDNS$kNWErrorDomainPOSIX$kNWErrorDomainTLS$"""
enums = """$NW_FRAMER_CREATE_FLAGS_DEFAULT@0$NW_FRAMER_WAKEUP_TIME_FOREVER@18446744073709551615$NW_LISTENER_INFINITE_CONNECTION_LIMIT@4294967295$NW_NOT_i386_MAC@1$nw_browse_result_change_identical@1$nw_browse_result_change_interface_added@8$nw_browse_result_change_interface_removed@16$nw_browse_result_change_invalid@0$nw_browse_result_change_result_added@2$nw_browse_result_change_result_removed@4$nw_browse_result_change_txt_record_changed@32$nw_browser_state_cancelled@3$nw_browser_state_failed@2$nw_browser_state_invalid@0$nw_browser_state_ready@1$nw_browser_state_waiting@4$nw_connection_group_state_cancelled@4$nw_connection_group_state_failed@3$nw_connection_group_state_invalid@0$nw_connection_group_state_ready@2$nw_connection_group_state_waiting@1$nw_connection_state_cancelled@5$nw_connection_state_failed@4$nw_connection_state_invalid@0$nw_connection_state_preparing@2$nw_connection_state_ready@3$nw_connection_state_waiting@1$nw_data_transfer_report_state_collected@2$nw_data_transfer_report_state_collecting@1$nw_endpoint_type_address@1$nw_endpoint_type_bonjour_service@3$nw_endpoint_type_host@2$nw_endpoint_type_invalid@0$nw_endpoint_type_url@4$nw_error_domain_dns@2$nw_error_domain_invalid@0$nw_error_domain_posix@1$nw_error_domain_tls@3$nw_ethernet_channel_state_cancelled@5$nw_ethernet_channel_state_failed@4$nw_ethernet_channel_state_invalid@0$nw_ethernet_channel_state_preparing@2$nw_ethernet_channel_state_ready@3$nw_ethernet_channel_state_waiting@1$nw_framer_start_result_ready@1$nw_framer_start_result_will_mark_ready@2$nw_interface_radio_type_cell_cdma@135$nw_interface_radio_type_cell_endc_mmw@130$nw_interface_radio_type_cell_endc_sub6@129$nw_interface_radio_type_cell_evdo@136$nw_interface_radio_type_cell_gsm@134$nw_interface_radio_type_cell_lte@128$nw_interface_radio_type_cell_nr_sa_mmw@132$nw_interface_radio_type_cell_nr_sa_sub6@131$nw_interface_radio_type_cell_wcdma@133$nw_interface_radio_type_unknown@0$nw_interface_radio_type_wifi_a@2$nw_interface_radio_type_wifi_ac@5$nw_interface_radio_type_wifi_ax@6$nw_interface_radio_type_wifi_b@1$nw_interface_radio_type_wifi_g@3$nw_interface_radio_type_wifi_n@4$nw_interface_type_cellular@2$nw_interface_type_loopback@4$nw_interface_type_other@0$nw_interface_type_wifi@1$nw_interface_type_wired@3$nw_ip_ecn_flag_ce@3$nw_ip_ecn_flag_ect_0@2$nw_ip_ecn_flag_ect_1@1$nw_ip_ecn_flag_non_ect@0$nw_ip_local_address_preference_default@0$nw_ip_local_address_preference_stable@2$nw_ip_local_address_preference_temporary@1$nw_ip_version_4@4$nw_ip_version_6@6$nw_ip_version_any@0$nw_listener_state_cancelled@4$nw_listener_state_failed@3$nw_listener_state_invalid@0$nw_listener_state_ready@2$nw_listener_state_waiting@1$nw_multipath_service_aggregate@3$nw_multipath_service_disabled@0$nw_multipath_service_handover@1$nw_multipath_service_interactive@2$nw_multipath_version_0@0$nw_multipath_version_1@1$nw_multipath_version_unspecified@-1$nw_parameters_attribution_developer@1$nw_parameters_attribution_user@2$nw_parameters_expired_dns_behavior_allow@1$nw_parameters_expired_dns_behavior_default@0$nw_parameters_expired_dns_behavior_prohibit@2$nw_path_status_invalid@0$nw_path_status_satisfiable@3$nw_path_status_satisfied@1$nw_path_status_unsatisfied@2$nw_path_unsatisfied_reason_cellular_denied@1$nw_path_unsatisfied_reason_local_network_denied@3$nw_path_unsatisfied_reason_not_available@0$nw_path_unsatisfied_reason_wifi_denied@2$nw_quic_stream_type_bidirectional@1$nw_quic_stream_type_unidirectional@2$nw_quic_stream_type_unknown@0$nw_report_resolution_protocol_https@4$nw_report_resolution_protocol_tcp@2$nw_report_resolution_protocol_tls@3$nw_report_resolution_protocol_udp@1$nw_report_resolution_protocol_unknown@0$nw_report_resolution_source_cache@2$nw_report_resolution_source_expired_cache@3$nw_report_resolution_source_query@1$nw_service_class_background@1$nw_service_class_best_effort@0$nw_service_class_interactive_video@2$nw_service_class_interactive_voice@3$nw_service_class_responsive_data@4$nw_service_class_signaling@5$nw_txt_record_find_key_empty_value@3$nw_txt_record_find_key_invalid@0$nw_txt_record_find_key_no_value@2$nw_txt_record_find_key_non_empty_value@4$nw_txt_record_find_key_not_present@1$nw_ws_close_code_abnormal_closure@1006$nw_ws_close_code_going_away@1001$nw_ws_close_code_internal_server_error@1011$nw_ws_close_code_invalid_frame_payload_data@1007$nw_ws_close_code_mandatory_extension@1010$nw_ws_close_code_message_too_big@1009$nw_ws_close_code_no_status_received@1005$nw_ws_close_code_normal_closure@1000$nw_ws_close_code_policy_violation@1008$nw_ws_close_code_protocol_error@1002$nw_ws_close_code_tls_handshake@1015$nw_ws_close_code_unsupported_data@1003$nw_ws_opcode_binary@2$nw_ws_opcode_close@8$nw_ws_opcode_cont@0$nw_ws_opcode_invalid@-1$nw_ws_opcode_ping@9$nw_ws_opcode_pong@10$nw_ws_opcode_text@1$nw_ws_response_status_accept@1$nw_ws_response_status_invalid@0$nw_ws_response_status_reject@2$nw_ws_version_13@1$nw_ws_version_invalid@0$"""
misc.update(
    {"nw_parameters_attribution_t": NewType("nw_parameters_attribution_t", int)}
)
misc.update({})
misc.update({})
functions = {
    "nw_txt_record_copy": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_framer_set_stop_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_establishment_report_copy_proxy_endpoint": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_listener_set_state_changed_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "i"},
                            2: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "nw_listener_create": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_connection_group_copy_remote_endpoint_for_message": (
        b"@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_parameters_set_local_only": (b"v@B",),
    "nw_parameters_create_custom_ip": (
        b"@C@?",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_protocol_options_copy_definition": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_browser_set_queue": (b"v@@",),
    "nw_connection_set_queue": (b"v@@",),
    "nw_protocol_metadata_is_quic": (b"B@",),
    "nw_path_is_constrained": (b"B@",),
    "nw_interface_get_name": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_protocol_metadata_copy_definition": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_txt_record_apply": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"c_array_delimited_by_null": True, "type": "n^t"},
                            2: {"type": "@"},
                            3: {"type": "n^v", "c_array_length_in_arg": 4},
                            4: {"type": "L"},
                        },
                    }
                }
            }
        },
    ),
    "nw_content_context_set_relative_priority": (b"v@d",),
    "nw_parameters_clear_prohibited_interfaces": (b"v@",),
    "nw_connection_start": (b"v@",),
    "nw_listener_set_new_connection_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_endpoint_get_hostname": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_parameters_create_secure_tcp": (
        b"@@?@?",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {
                0: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                },
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                },
            },
        },
    ),
    "nw_quic_set_max_udp_payload_size": (b"v@S",),
    "nw_quic_get_initial_max_data": (b"Q@",),
    "nw_content_context_set_expiration_milliseconds": (b"v@Q",),
    "nw_framer_message_set_object_value": (
        b"v@^t@",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "nw_connection_group_cancel": (b"v@",),
    "nw_path_is_equal": (b"B@@",),
    "nw_connection_force_cancel": (b"v@",),
    "nw_ip_metadata_get_service_class": (b"I@",),
    "nw_parameters_create": (b"@", "", {"retval": {"already_retained": True}}),
    "nw_tcp_options_set_disable_ack_stretching": (b"v@B",),
    "nw_framer_message_set_value": (
        b"v@^t^v@?",
        "",
        {
            "arguments": {
                1: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "^v"}},
                    }
                },
            }
        },
    ),
    "nw_quic_get_stream_is_unidirectional": (b"B@",),
    "nw_resolution_report_copy_successful_endpoint": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_content_context_foreach_protocol_metadata": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                        },
                    },
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}, 1: {"type": b"@"}},
                    },
                }
            }
        },
    ),
    "nw_content_context_set_is_final": (b"v@B",),
    "nw_tls_copy_sec_protocol_options": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_quic_get_local_max_streams_unidirectional": (b"Q@",),
    "nw_quic_set_initial_max_data": (b"v@Q",),
    "nw_advertise_descriptor_get_no_auto_rename": (b"B@",),
    "nw_connection_group_copy_protocol_metadata": (
        b"@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_protocol_metadata_is_ip": (b"B@",),
    "nw_endpoint_get_type": (b"I@",),
    "nw_path_enumerate_gateways": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_protocol_stack_clear_application_protocols": (b"v@",),
    "nw_udp_create_metadata": (b"@", "", {"retval": {"already_retained": True}}),
    "nw_advertise_descriptor_get_application_service_name": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_quic_get_initial_max_stream_data_bidirectional_local": (b"Q@",),
    "nw_parameters_set_attribution": (b"v@C",),
    "nw_resolver_config_add_server_address": (b"v@@",),
    "nw_advertise_descriptor_set_txt_record": (
        b"v@^vQ",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}}},
    ),
    "nw_tcp_options_set_no_push": (b"v@B",),
    "nw_connection_copy_protocol_metadata": (
        b"@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_ws_create_metadata": (b"@i", "", {"retval": {"already_retained": True}}),
    "nw_connection_get_maximum_datagram_size": (b"I@",),
    "nw_resolution_report_get_endpoint_count": (b"I@",),
    "nw_quic_copy_sec_protocol_metadata": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_connection_group_copy_protocol_metadata_for_message": (
        b"@@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_connection_receive_message": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                            3: {"type": "B"},
                            4: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "nw_ip_options_set_local_address_preference": (b"v@I",),
    "nw_endpoint_copy_address_string": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_listener_set_new_connection_group_handler": (b"v@@?",),
    "nw_tcp_options_set_connection_timeout": (b"v@I",),
    "nw_connection_set_viability_changed_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "B"}},
                    }
                }
            }
        },
    ),
    "nw_ethernet_channel_create_with_parameters": (
        b"@S@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_connection_group_set_queue": (b"v@@",),
    "nw_ip_options_set_disable_fragmentation": (b"v@B",),
    "nw_error_get_error_domain": (b"I@",),
    "nw_framer_options_copy_object_value": (
        b"@@^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "nw_framer_mark_ready": (b"v@",),
    "nw_ws_request_enumerate_additional_headers": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"c_array_delimited_by_null": True, "type": "n^t"},
                            2: {"c_array_delimited_by_null": True, "type": "n^t"},
                        },
                    }
                }
            }
        },
    ),
    "nw_parameters_get_fast_open_enabled": (b"B@",),
    "nw_parameters_copy_required_interface": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_establishment_report_get_duration_milliseconds": (b"Q@",),
    "nw_browse_descriptor_set_include_txt_record": (b"v@B",),
    "nw_protocol_stack_iterate_application_protocols": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_ip_options_set_hop_limit": (b"v@C",),
    "nw_establishment_report_enumerate_resolution_reports": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_connection_set_state_changed_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "i"},
                            2: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "nw_browser_set_state_changed_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "nw_ethernet_channel_set_queue": (b"v@@",),
    "nw_ethernet_channel_cancel": (b"v@",),
    "nw_path_monitor_start": (b"v@",),
    "nw_parameters_clear_prohibited_interface_types": (b"v@",),
    "nw_connection_copy_description": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}, "free_result": True},
    ),
    "nw_parameters_create_quic": (b"@@?", "", {"retval": {"already_retained": True}}),
    "nw_listener_set_queue": (b"v@@",),
    "nw_tcp_create_options": (b"@", "", {"retval": {"already_retained": True}}),
    "nw_ip_options_set_version": (b"v@I",),
    "nw_establishment_report_get_proxy_configured": (b"B@",),
    "nw_connection_group_copy_descriptor": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_parameters_iterate_prohibited_interface_types": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "i"}},
                    }
                }
            }
        },
    ),
    "nw_path_has_ipv6": (b"B@",),
    "nw_path_has_ipv4": (b"B@",),
    "nw_connection_cancel_current_endpoint": (b"v@",),
    "nw_quic_get_stream_is_datagram": (b"B@",),
    "nw_framer_message_access_value": (
        b"B@^t@?",
        "",
        {
            "arguments": {
                1: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                2: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "^v"}},
                    },
                    "block": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": b"^v"}},
                    },
                },
            }
        },
    ),
    "nw_framer_copy_remote_endpoint": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_quic_get_stream_id": (b"Q@",),
    "nw_listener_get_new_connection_limit": (b"I@",),
    "nw_browse_descriptor_get_bonjour_service_type": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_endpoint_copy_txt_record": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_endpoint_get_port": (b"S@",),
    "nw_parameters_get_multipath_service": (b"I@",),
    "nw_parameters_set_local_endpoint": (b"v@@",),
    "nw_ethernet_channel_set_state_changed_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "nw_parameters_get_service_class": (b"I@",),
    "nw_privacy_context_create": (
        b"@^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {0: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "nw_framer_create_definition": (
        b"@^tI@?",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {
                0: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                2: {
                    "callable": {
                        "retval": {"type": b"i"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                },
            },
        },
    ),
    "nw_ws_options_set_auto_reply_ping": (b"v@B",),
    "nw_protocol_copy_tls_definition": (
        b"@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_path_monitor_set_update_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_multicast_group_descriptor_get_disable_unicast_traffic": (b"B@",),
    "nw_establishment_report_enumerate_resolutions": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "Q"},
                            3: {"type": "I"},
                            4: {"type": "@"},
                            5: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "nw_framer_copy_parameters": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_txt_record_is_dictionary": (b"B@",),
    "nw_quic_get_local_max_streams_bidirectional": (b"Q@",),
    "nw_parameters_get_attribution": (b"C@",),
    "nw_ip_options_set_disable_multicast_loopback": (b"v@B",),
    "nw_interface_get_type": (b"I@",),
    "nw_endpoint_create_url": (
        b"@^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {0: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "nw_endpoint_copy_port_string": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_quic_get_stream_type": (b"C@",),
    "nw_parameters_set_requires_dnssec_validation": (b"v@B",),
    "nw_path_monitor_set_queue": (b"v@@",),
    "nw_ethernet_channel_get_maximum_payload_size": (b"I@",),
    "nw_protocol_stack_copy_internet_protocol": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_privacy_context_disable_logging": (b"v@",),
    "nw_framer_message_create": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_connection_group_copy_parameters": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_path_monitor_set_cancel_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}},
                    }
                }
            }
        },
    ),
    "nw_quic_set_initial_max_stream_data_bidirectional_remote": (b"v@Q",),
    "nw_quic_set_keepalive_interval": (b"v@S",),
    "nw_establishment_report_get_attempt_started_after_milliseconds": (b"Q@",),
    "nw_advertise_descriptor_set_txt_record_object": (b"v@@",),
    "nw_connection_group_set_receive_handler": (
        b"v@IB@?",
        "",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                            3: {"type": "B"},
                        },
                    }
                }
            }
        },
    ),
    "nw_protocol_metadata_is_tls": (b"B@",),
    "nw_protocol_stack_set_transport_protocol": (b"v@@",),
    "nw_quic_get_stream_application_error": (b"Q@",),
    "nw_framer_write_output_no_copy": (b"B@Q",),
    "nw_connection_create": (b"@@@", "", {"retval": {"already_retained": True}}),
    "nw_browser_create": (b"@@@", "", {"retval": {"already_retained": True}}),
    "nw_ip_metadata_get_ecn_flag": (b"I@",),
    "nw_protocol_options_is_quic": (b"B@",),
    "nw_connection_set_better_path_available_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "B"}},
                    }
                }
            }
        },
    ),
    "nw_tcp_options_set_disable_ecn": (b"v@B",),
    "nw_data_transfer_report_get_path_count": (b"I@",),
    "nw_quic_set_initial_max_stream_data_unidirectional": (b"v@Q",),
    "nw_framer_write_output": (
        b"v@n^vQ",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "nw_endpoint_create_bonjour_service": (
        b"@^t^t^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {
                0: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                1: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                2: {"c_array_delimited_by_null": True, "type_modifier": "n"},
            },
        },
    ),
    "nw_browse_result_get_interfaces_count": (b"Q@",),
    "nw_parameters_prohibit_interface_type": (b"v@I",),
    "nw_parameters_copy_local_endpoint": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_connection_group_start": (b"v@",),
    "nw_ethernet_channel_set_receive_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "S"},
                            3: {"type": "n[6t]"},
                            4: {"type": "n[6t]"},
                        },
                    }
                }
            }
        },
    ),
    "nw_parameters_set_prefer_no_proxy": (b"v@B",),
    "nw_udp_options_set_prefer_no_checksum": (b"v@B",),
    "nw_privacy_context_flush_cache": (b"v@",),
    "nw_establishment_report_get_used_proxy": (b"B@",),
    "nw_content_context_get_is_final": (b"B@",),
    "nw_quic_create_options": (b"@", "", {"retval": {"already_retained": True}}),
    "nw_tcp_options_set_no_options": (b"v@B",),
    "nw_resolution_report_get_source": (b"I@",),
    "nw_data_transfer_report_get_sent_transport_byte_count": (b"Q@I",),
    "nw_connection_access_establishment_report": (
        b"v@@@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_parameters_set_required_interface_type": (b"v@I",),
    "nw_content_context_set_antecedent": (b"v@@",),
    "nw_parameters_requires_dnssec_validation": (b"B@",),
    "nw_ws_response_get_selected_subprotocol": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_parameters_get_local_only": (b"B@",),
    "nw_framer_options_set_object_value": (
        b"v@^t@",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "nw_listener_start": (b"v@",),
    "nw_resolution_report_copy_preferred_endpoint": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_resolver_config_create_https": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_txt_record_create_dictionary": (
        b"@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_ws_create_options": (b"@I", "", {"retval": {"already_retained": True}}),
    "nw_parameters_create_application_service": (
        b"@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_framer_mark_failed_with_error": (b"v@i",),
    "nw_tcp_options_set_keepalive_idle_time": (b"v@I",),
    "nw_error_get_error_code": (b"i@",),
    "nw_quic_set_max_datagram_frame_size": (b"v@S",),
    "nw_quic_add_tls_application_protocol": (
        b"v@^t",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "nw_ip_metadata_set_service_class": (b"v@I",),
    "nw_parameters_iterate_prohibited_interfaces": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_parameters_set_reuse_local_address": (b"v@B",),
    "nw_quic_set_initial_max_streams_unidirectional": (b"v@Q",),
    "nw_ethernet_channel_create": (b"@S@", "", {"retval": {"already_retained": True}}),
    "nw_txt_record_is_equal": (b"B@@",),
    "nw_framer_prepend_application_protocol": (b"B@@",),
    "nw_protocol_copy_quic_definition": (
        b"@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_ws_request_enumerate_subprotocols": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"c_array_delimited_by_null": True, "type": "n^t"},
                        },
                    }
                }
            }
        },
    ),
    "nw_tls_create_options": (b"@",),
    "nw_advertise_descriptor_copy_txt_record_object": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_txt_record_remove_key": (
        b"B@n^t",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True}}},
    ),
    "nw_data_transfer_report_collect": (
        b"v@@@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_content_context_get_relative_priority": (b"d@",),
    "nw_txt_record_access_bytes": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "n^v", "c_array_length_in_arg": 2},
                            2: {"type": "L"},
                        },
                    }
                }
            }
        },
    ),
    "nw_browse_descriptor_get_include_txt_record": (b"B@",),
    "nw_path_has_dns": (b"B@",),
    "nw_quic_get_remote_max_streams_unidirectional": (b"Q@",),
    "nw_quic_set_idle_timeout": (b"v@I",),
    "nw_browser_start": (b"v@",),
    "nw_browse_descriptor_create_bonjour_service": (
        b"@^t^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {
                0: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                1: {"c_array_delimited_by_null": True, "type_modifier": "n"},
            },
        },
    ),
    "nw_framer_set_output_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                            3: {"type": "L"},
                            4: {"type": "B"},
                        },
                    }
                }
            }
        },
    ),
    "nw_quic_set_stream_application_error": (b"v@Q",),
    "nw_parameters_set_multipath_service": (b"v@I",),
    "nw_framer_pass_through_output": (b"v@",),
    "nw_udp_create_options": (b"@", "", {"retval": {"already_retained": True}}),
    "nw_ws_metadata_copy_server_response": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_listener_set_new_connection_limit": (b"v@I",),
    "nw_ws_response_add_additional_header": (
        b"v@n^tn^t",
        "",
        {
            "arguments": {
                1: {"c_array_delimited_by_null": True},
                2: {"c_array_delimited_by_null": True},
            }
        },
    ),
    "nw_framer_set_input_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"L"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_txt_record_get_key_count": (b"Q@",),
    "nw_quic_set_local_max_streams_bidirectional": (b"v@Q",),
    "nw_protocol_copy_udp_definition": (
        b"@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_ws_metadata_set_close_code": (b"v@I",),
    "nw_quic_get_initial_max_stream_data_unidirectional": (b"Q@",),
    "nw_quic_get_initial_max_streams_unidirectional": (b"Q@",),
    "nw_ip_metadata_get_receive_time": (b"Q@",),
    "nw_ws_options_add_subprotocol": (
        b"v@^t",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "nw_txt_record_create_with_bytes": (
        b"@n^vQ",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {0: {"c_array_length_in_arg": 1}},
        },
    ),
    "nw_tcp_options_set_keepalive_count": (b"v@I",),
    "nw_tcp_options_set_multipath_force_version": (b"v@i",),
    "nw_endpoint_get_address": (
        b"^{sockaddr=CC[14c]}@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_quic_get_max_udp_payload_size": (b"S@",),
    "nw_tcp_options_set_retransmit_connection_drop_time": (b"v@I",),
    "nw_data_transfer_report_get_sent_transport_retransmitted_byte_count": (b"Q@I",),
    "nw_content_context_copy_protocol_metadata": (
        b"@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_data_transfer_report_get_received_transport_out_of_order_byte_count": (b"Q@I",),
    "nw_browse_result_enumerate_interfaces": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_protocol_metadata_is_framer_message": (b"B@",),
    "nw_endpoint_create_address": (
        b"@^{sockaddr=CC[14c]}",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {0: {"type_modifier": "n"}},
        },
    ),
    "nw_quic_get_initial_max_stream_data_bidirectional_remote": (b"Q@",),
    "nw_advertise_descriptor_create_application_service": (
        b"@^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {0: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "nw_quic_get_keepalive_interval": (b"S@",),
    "nw_connection_batch": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}},
                    }
                }
            }
        },
    ),
    "nw_parameters_get_include_peer_to_peer": (b"B@",),
    "nw_framer_parse_input": (
        b"B@QQ^C@?",
        "",
        {
            "arguments": {
                3: {"c_array_length_in_arg": 2, "type_modifier": "n"},
                4: {
                    "callable": {
                        "retval": {"type": b"L"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "n^v", "c_array_length_in_arg": 2},
                            2: {"type": "L"},
                            3: {"type": "B"},
                        },
                    }
                },
            }
        },
    ),
    "nw_framer_copy_options": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_data_transfer_report_get_state": (b"I@",),
    "nw_quic_get_stream_usable_datagram_frame_size": (b"S@",),
    "nw_ws_metadata_get_opcode": (b"i@",),
    "nw_framer_schedule_wakeup": (b"v@Q",),
    "nw_data_transfer_report_get_received_transport_byte_count": (b"Q@I",),
    "nw_endpoint_get_bonjour_service_domain": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_resolver_config_create_tls": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_path_is_expensive": (b"B@",),
    "nw_quic_get_idle_timeout": (b"I@",),
    "nw_group_descriptor_enumerate_endpoints": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_ws_metadata_set_pong_handler": (
        b"v@@@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_path_monitor_prohibit_interface_type": (b"v@I",),
    "nw_endpoint_get_bonjour_service_type": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_connection_copy_endpoint": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_content_context_copy_antecedent": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_tcp_options_set_maximum_segment_size": (b"v@I",),
    "nw_framer_pass_through_input": (b"v@",),
    "nw_browser_copy_browse_descriptor": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_data_transfer_report_get_duration_milliseconds": (b"Q@",),
    "nw_protocol_metadata_is_tcp": (b"B@",),
    "nw_endpoint_get_bonjour_service_name": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_parameters_get_expired_dns_behavior": (b"I@",),
    "nw_framer_async": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}},
                    }
                }
            }
        },
    ),
    "nw_connection_group_set_new_connection_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_connection_copy_current_path": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_path_copy_effective_remote_endpoint": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_browse_descriptor_get_bonjour_service_domain": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_quic_get_remote_max_streams_bidirectional": (b"Q@",),
    "nw_connection_copy_parameters": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_quic_set_initial_max_stream_data_bidirectional_local": (b"v@Q",),
    "nw_browser_copy_parameters": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_quic_set_application_error": (
        b"v@Q^t",
        "",
        {"arguments": {2: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "nw_quic_get_max_datagram_frame_size": (b"S@",),
    "nw_txt_record_set_key": (
        b"B@n^vn^vQ",
        "",
        {
            "arguments": {
                1: {"c_array_delimited_by_null": True},
                2: {"c_array_length_in_arg": 3},
            }
        },
    ),
    "nw_ws_response_get_status": (b"I@",),
    "nw_content_context_get_expiration_milliseconds": (b"Q@",),
    "nw_group_descriptor_add_endpoint": (b"B@@",),
    "nw_resolution_report_get_protocol": (
        b"I@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_quic_set_initial_max_streams_bidirectional": (b"v@Q",),
    "nw_group_descriptor_create_multicast": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_framer_set_wakeup_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_listener_set_advertise_descriptor": (b"v@@",),
    "nw_parameters_prohibit_interface": (b"v@@",),
    "nw_quic_get_initial_max_streams_bidirectional": (b"Q@",),
    "nw_establishment_report_get_previous_attempt_count": (b"I@",),
    "nw_establishment_report_enumerate_protocols": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "Q"},
                            3: {"type": "Q"},
                        },
                    }
                }
            }
        },
    ),
    "nw_quic_get_application_error_reason": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_endpoint_get_url": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_data_transfer_report_get_sent_ip_packet_count": (b"Q@I",),
    "nw_tcp_get_available_send_buffer": (b"I@",),
    "nw_protocol_stack_copy_transport_protocol": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_data_transfer_report_copy_path_interface": (
        b"@@I",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_protocol_copy_tcp_definition": (
        b"@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_data_transfer_report_get_sent_application_byte_count": (b"Q@I",),
    "nw_connection_group_extract_connection_for_message": (
        b"@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_path_copy_effective_local_endpoint": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_parameters_get_required_interface_type": (b"I@",),
    "nw_ws_options_set_skip_handshake": (b"v@B",),
    "nw_ws_response_enumerate_additional_headers": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"c_array_delimited_by_null": True, "type": "n^t"},
                            2: {"c_array_delimited_by_null": True, "type": "n^t"},
                        },
                    }
                }
            }
        },
    ),
    "nw_protocol_stack_prepend_application_protocol": (b"v@@",),
    "nw_tcp_options_set_retransmit_fin_drop": (b"v@B",),
    "nw_listener_get_port": (b"S@",),
    "nw_group_descriptor_create_multiplex": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_browse_descriptor_create_application_service": (
        b"@^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {0: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "nw_endpoint_get_signature": (
        b"^t@^Q",
        "",
        {
            "retval": {"c_array_length_in_arg": 1},
            "arguments": {1: {"type_modifier": "o"}},
        },
    ),
    "nw_ws_response_create": (
        b"@I^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {1: {"c_array_length_in_arg": 2, "type_modifier": "n"}},
        },
    ),
    "nw_connection_set_path_changed_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_protocol_metadata_is_udp": (b"B@",),
    "nw_content_context_get_identifier": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_browser_cancel": (b"v@",),
    "nw_connection_cancel": (b"v@",),
    "nw_ip_options_set_calculate_receive_time": (b"v@B",),
    "nw_interface_get_index": (b"I@",),
    "nw_data_transfer_report_get_received_application_byte_count": (b"Q@I",),
    "nw_framer_deliver_input_no_copy": (b"B@Q@B",),
    "nw_browse_result_copy_txt_record_object": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_connection_restart": (b"v@",),
    "nw_ip_metadata_set_ecn_flag": (b"v@I",),
    "nw_advertise_descriptor_create_bonjour_service": (
        b"@^t^t^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {
                0: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                1: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                2: {"c_array_delimited_by_null": True, "type_modifier": "n"},
            },
        },
    ),
    "nw_connection_group_create": (b"@@@", "", {"retval": {"already_retained": True}}),
    "nw_parameters_set_expired_dns_behavior": (b"v@I",),
    "nw_parameters_get_reuse_local_address": (b"B@",),
    "nw_connection_create_new_data_transfer_report": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_connection_group_set_state_changed_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "i"},
                            2: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "nw_connection_group_reply": (b"v@@@@",),
    "nw_privacy_context_require_encrypted_name_resolution": (b"v@B@",),
    "nw_parameters_set_include_peer_to_peer": (b"v@B",),
    "nw_framer_set_cleanup_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_content_context_create": (
        b"@^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {0: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "nw_browse_descriptor_get_application_service_name": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "nw_ws_options_set_client_request_handler": (
        b"v@@@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_advertise_descriptor_set_no_auto_rename": (b"v@B",),
    "nw_data_transfer_report_get_path_radio_type": (b"I@I",),
    "nw_quic_set_stream_is_datagram": (b"v@B",),
    "nw_ip_options_set_use_minimum_mtu": (b"v@B",),
    "nw_ws_options_set_maximum_message_size": (b"v@Q",),
    "nw_error_copy_cf_error": (
        b"^{__CFError=}@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "nw_tcp_options_set_persist_timeout": (b"v@I",),
    "nw_parameters_require_interface": (b"v@@",),
    "nw_ip_create_metadata": (b"@", "", {"retval": {"already_retained": True}}),
    "nw_tls_copy_sec_protocol_metadata": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_listener_create_with_connection": (
        b"@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_path_monitor_create_with_type": (
        b"@I",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_parameters_set_service_class": (b"v@I",),
    "nw_connection_group_copy_path_for_message": (b"@@@",),
    "nw_parameters_set_privacy_context": (b"v@@",),
    "nw_framer_parse_output": (
        b"B@QQ^C@?",
        "",
        {
            "arguments": {
                3: {"c_array_length_in_arg": 2, "type_modifier": "o"},
                4: {
                    "callable": {
                        "retval": {"type": b"L"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "n^v", "c_array_length_in_arg": 2},
                            2: {"type": "L"},
                            3: {"type": "B"},
                        },
                    }
                },
            }
        },
    ),
    "nw_framer_message_copy_object_value": (
        b"@@^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "nw_data_transfer_report_get_received_transport_duplicate_byte_count": (b"Q@I",),
    "nw_txt_record_access_key": (
        b"B@^t@?",
        "",
        {
            "arguments": {
                1: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                2: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"c_array_delimited_by_null": True, "type": "n^t"},
                            2: {"type": "@"},
                            3: {"type": "n^v", "c_array_length_in_arg": 4},
                            4: {"type": "L"},
                        },
                    }
                },
            }
        },
    ),
    "nw_tcp_get_available_receive_buffer": (b"I@",),
    "nw_tcp_options_set_no_delay": (b"v@B",),
    "nw_path_monitor_create_for_ethernet_channel": (
        b"@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_path_enumerate_interfaces": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_connection_group_extract_connection": (
        b"@@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_browser_set_browse_results_changed_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                            3: {"type": "B"},
                        },
                    }
                }
            }
        },
    ),
    "nw_protocol_definition_is_equal": (b"B@@",),
    "nw_parameters_set_prohibit_expensive": (b"v@B",),
    "nw_parameters_set_fast_open_enabled": (b"v@B",),
    "nw_ethernet_channel_send": (
        b"v@@S^C@?",
        "",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_data_transfer_report_get_transport_smoothed_rtt_milliseconds": (b"Q@I",),
    "nw_ws_metadata_get_close_code": (b"I@",),
    "nw_tcp_options_set_keepalive_interval": (b"v@I",),
    "nw_path_get_status": (b"I@",),
    "nw_txt_record_find_key": (
        b"I@n^t",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True}}},
    ),
    "nw_resolution_report_get_milliseconds": (b"Q@",),
    "nw_ws_options_add_additional_header": (
        b"v@^t^t",
        "",
        {
            "arguments": {
                1: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                2: {"c_array_delimited_by_null": True, "type_modifier": "n"},
            }
        },
    ),
    "nw_path_get_unsatisfied_reason": (b"I@",),
    "nw_browse_result_copy_endpoint": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_parameters_get_prohibit_constrained": (b"B@",),
    "nw_endpoint_create_host": (
        b"@^t^t",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {
                0: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                1: {"c_array_delimited_by_null": True, "type_modifier": "n"},
            },
        },
    ),
    "nw_framer_write_output_data": (b"v@@",),
    "nw_connection_group_send_message": (
        b"v@@@@@?",
        "",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_parameters_set_prohibit_constrained": (b"v@B",),
    "nw_connection_group_reinsert_extracted_connection": (b"B@@",),
    "nw_parameters_copy_default_protocol_stack": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_quic_copy_sec_protocol_options": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_path_monitor_cancel": (b"v@",),
    "nw_listener_set_advertised_endpoint_changed_handler": (
        b"v@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "B"},
                        },
                    }
                }
            }
        },
    ),
    "nw_quic_get_application_error": (b"Q@",),
    "nw_parameters_get_prohibit_expensive": (b"B@",),
    "nw_content_context_set_metadata_for_protocol": (b"v@@",),
    "nw_framer_create_options": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_parameters_get_prefer_no_proxy": (b"B@",),
    "nw_protocol_metadata_is_ws": (b"B@",),
    "nw_tcp_options_set_enable_keepalive": (b"v@B",),
    "nw_tcp_options_set_enable_fast_open": (b"v@B",),
    "nw_framer_protocol_create_message": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_ethernet_channel_start": (b"v@",),
    "nw_parameters_copy": (b"@@", "", {"retval": {"already_retained": True}}),
    "nw_listener_cancel": (b"v@",),
    "nw_quic_get_remote_idle_timeout": (b"Q@",),
    "nw_browse_result_get_changes": (b"Q@@",),
    "nw_connection_send": (
        b"v@@@B@?",
        "",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "nw_multicast_group_descriptor_set_disable_unicast_traffic": (b"v@B",),
    "nw_path_uses_interface_type": (b"B@I",),
    "nw_data_transfer_report_get_transport_rtt_variance": (b"Q@I",),
    "nw_quic_set_local_max_streams_unidirectional": (b"v@Q",),
    "nw_connection_receive": (
        b"v@II@?",
        "",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                            3: {"type": "B"},
                            4: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "nw_framer_copy_local_endpoint": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_protocol_copy_ip_definition": (b"@",),
    "nw_multicast_group_descriptor_set_specific_source": (b"v@@",),
    "nw_connection_group_copy_local_endpoint_for_message": (
        b"@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_quic_set_stream_is_unidirectional": (b"v@B",),
    "nw_data_transfer_report_get_received_ip_packet_count": (b"Q@I",),
    "nw_parameters_create_secure_udp": (
        b"@@?@?",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {
                0: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                },
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                },
            },
        },
    ),
    "nw_path_monitor_create": (b"@", "", {"retval": {"already_retained": True}}),
    "nw_listener_create_with_port": (
        b"@^t@",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {0: {"c_array_delimited_by_null": True, "type_modifier": "n"}},
        },
    ),
    "nw_protocol_copy_ws_definition": (
        b"@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "nw_data_transfer_report_get_transport_minimum_rtt_milliseconds": (b"Q@I",),
    "nw_framer_deliver_input": (
        b"v@n^vQ@B",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
}
aliases = {
    "NW_RETURNS_RETAINED": "OS_OBJECT_RETURNS_RETAINED",
    "NW_LISTENER_INFINITE_CONNECTION_LIMIT": "UINT32_MAX",
    "NW_EXPORT_PROJECT": "NW_EXPORT",
    "NW_ALL_PATHS": "_nw_data_transfer_report_all_paths",
    "NW_NONNULL_ARRAY": "_Nonnull",
    "NW_UNSAFE_UNRETAINED": "__unsafe_unretained",
}
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network


class TestTCPOptions(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_multipath_version_unspecified, -1)
        self.assertEqual(Network.nw_multipath_version_0, 0)
        self.assertEqual(Network.nw_multipath_version_1, 1)

    def test_functions(self):
        self.assertResultIsRetained(Network.nw_protocol_copy_tcp_definition)

        self.assertResultIsRetained(Network.nw_tcp_create_options)

        Network.nw_tcp_options_set_no_delay
        Network.nw_tcp_options_set_no_push
        Network.nw_tcp_options_set_no_options
        Network.nw_tcp_options_set_enable_keepalive
        Network.nw_tcp_options_set_keepalive_count
        Network.nw_tcp_options_set_keepalive_idle_time
        Network.nw_tcp_options_set_keepalive_interval
        Network.nw_tcp_options_set_maximum_segment_size
        Network.nw_tcp_options_set_connection_timeout
        Network.nw_tcp_options_set_persist_timeout
        Network.nw_tcp_options_set_retransmit_connection_drop_time
        Network.nw_tcp_options_set_retransmit_fin_drop
        Network.nw_tcp_options_set_disable_ack_stretching
        Network.nw_tcp_options_set_enable_fast_open
        Network.nw_tcp_options_set_disable_ecn
        Network.nw_protocol_metadata_is_tcp
        Network.nw_tcp_get_available_receive_buffer
        Network.nw_tcp_get_available_send_buffer

    @min_os_level("12.0")
    def test_functions12_0(self):
        Network.nw_tcp_options_set_multipath_force_version



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import Network

nw_parameters_configure_protocol_block_t = b"v@"
nw_parameters_iterate_interfaces_block_t = b"B@"
nw_parameters_iterate_interface_types_block_t = b"Bi"
nw_protocol_stack_iterate_protocols_block_t = b"v@"


class TestParameters(TestCase):
    def test_constants(self):
        self.assertIsInstance(
            Network.NW_PARAMETERS_DEFAULT_CONFIGURATION, objc.objc_object
        )
        self.assertIsInstance(Network.NW_PARAMETERS_DISABLE_PROTOCOL, objc.objc_object)

        self.assertEqual(Network.nw_service_class_best_effort, 0)
        self.assertEqual(Network.nw_service_class_background, 1)
        self.assertEqual(Network.nw_service_class_interactive_video, 2)
        self.assertEqual(Network.nw_service_class_interactive_voice, 3)
        self.assertEqual(Network.nw_service_class_responsive_data, 4)
        self.assertEqual(Network.nw_service_class_signaling, 5)

        self.assertEqual(Network.nw_multipath_service_disabled, 0)
        self.assertEqual(Network.nw_multipath_service_handover, 1)
        self.assertEqual(Network.nw_multipath_service_interactive, 2)
        self.assertEqual(Network.nw_multipath_service_aggregate, 3)

        self.assertEqual(Network.nw_parameters_expired_dns_behavior_default, 0)
        self.assertEqual(Network.nw_parameters_expired_dns_behavior_allow, 1)
        self.assertEqual(Network.nw_parameters_expired_dns_behavior_prohibit, 2)

        self.assertEqual(Network.nw_parameters_attribution_developer, 1)
        self.assertEqual(Network.nw_parameters_attribution_user, 2)

    def test_functions(self):
        self.assertResultIsRetained(Network.nw_parameters_create_secure_tcp)
        self.assertArgIsBlock(
            Network.nw_parameters_create_secure_tcp,
            1,
            nw_parameters_configure_protocol_block_t,
        )

        self.assertResultIsRetained(Network.nw_parameters_create_secure_udp)
        self.assertArgIsBlock(
            Network.nw_parameters_create_secure_udp,
            1,
            nw_parameters_configure_protocol_block_t,
        )

        self.assertResultIsRetained(Network.nw_parameters_create)
        self.assertResultIsRetained(Network.nw_parameters_copy)

        Network.nw_parameters_require_interface
        self.assertResultIsRetained(Network.nw_parameters_copy_required_interface)

        Network.nw_parameters_prohibit_interface
        Network.nw_parameters_clear_prohibited_interfaces

        self.assertArgIsBlock(
            Network.nw_parameters_iterate_prohibited_interfaces,
            1,
            nw_parameters_iterate_interfaces_block_t,
        )

        Network.nw_parameters_set_required_interface_type
        Network.nw_parameters_get_required_interface_type
        Network.nw_parameters_prohibit_interface_type

        Network.nw_parameters_clear_prohibited_interface_types

        self.assertArgIsBlock(
            Network.nw_parameters_iterate_prohibited_interface_types,
            1,
            nw_parameters_iterate_interface_types_block_t,
        )

        Network.nw_parameters_set_prohibit_expensive
        Network.nw_parameters_get_prohibit_expensive
        Network.nw_parameters_set_reuse_local_address
        Network.nw_parameters_get_reuse_local_address
        Network.nw_parameters_set_local_endpoint

        self.assertResultIsRetained(Network.nw_parameters_copy_local_endpoint)

        Network.nw_parameters_set_fast_open_enabled
        Network.nw_parameters_get_fast_open_enabled
        Network.nw_parameters_set_service_class
        Network.nw_parameters_get_service_class
        Network.nw_parameters_set_multipath_service
        Network.nw_parameters_get_multipath_service

        self.assertResultIsRetained(Network.nw_parameters_copy_default_protocol_stack)

        Network.nw_protocol_stack_prepend_application_protocol
        Network.nw_protocol_stack_clear_application_protocols

        self.assertArgIsBlock(
            Network.nw_protocol_stack_iterate_application_protocols,
            1,
            nw_protocol_stack_iterate_protocols_block_t,
        )

        self.assertResultIsRetained(Network.nw_protocol_stack_copy_transport_protocol)

        Network.nw_protocol_stack_set_transport_protocol

        self.assertResultIsRetained(Network.nw_protocol_stack_copy_internet_protocol)

        Network.nw_parameters_set_local_only
        Network.nw_parameters_get_local_only
        Network.nw_parameters_set_prefer_no_proxy
        Network.nw_parameters_get_prefer_no_proxy
        Network.nw_parameters_set_expired_dns_behavior
        Network.nw_parameters_get_expired_dns_behavior
        Network.nw_parameters_set_include_peer_to_peer
        Network.nw_parameters_get_include_peer_to_peer

    @min_os_level("10.15")
    def test_functions10_15(self):
        self.assertResultIsRetained(Network.nw_parameters_create_custom_ip)

        Network.nw_parameters_set_prohibit_constrained
        Network.nw_parameters_get_prohibit_constrained

    @min_os_level("11.0")
    def test_functions11_0(self):
        Network.nw_parameters_set_privacy_context

    @min_os_level("12.0")
    def test_functions12_0(self):
        self.assertResultIsRetained(Network.nw_parameters_create_quic)
        Network.nw_parameters_set_attribution
        Network.nw_parameters_get_attribution

    @min_os_level("13.0")
    def test_functions13_0(self):
        self.assertResultIsRetained(Network.nw_parameters_create_application_service)
        Network.nw_parameters_set_requires_dnssec_validation
        Network.nw_parameters_requires_dnssec_validation



from PyObjCTools.TestSupport import TestCase

import Network


class TestTLSOptions(TestCase):
    def test_functions(self):
        self.assertResultIsRetained(Network.nw_protocol_copy_tls_definition)

        Network.nw_tls_create_options

        self.assertResultIsRetained(Network.nw_tls_copy_sec_protocol_options)

        Network.nw_protocol_metadata_is_tls

        self.assertResultIsRetained(Network.nw_tls_copy_sec_protocol_metadata)



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network


class TestQUICOptions(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_quic_stream_type_unknown, 0)
        self.assertEqual(Network.nw_quic_stream_type_bidirectional, 1)
        self.assertEqual(Network.nw_quic_stream_type_unidirectional, 2)

    @min_os_level("12.0")
    def test_functions12_0(self):
        self.assertResultIsRetained(Network.nw_protocol_copy_quic_definition)
        self.assertResultIsRetained(Network.nw_quic_create_options)
        Network.nw_protocol_options_is_quic
        Network.nw_quic_add_tls_application_protocol
        self.assertResultIsRetained(Network.nw_quic_copy_sec_protocol_options)
        Network.nw_quic_get_stream_is_unidirectional
        Network.nw_quic_set_stream_is_unidirectional
        Network.nw_quic_get_initial_max_data
        Network.nw_quic_set_initial_max_data
        Network.nw_quic_get_max_udp_payload_size
        Network.nw_quic_set_max_udp_payload_size
        Network.nw_quic_get_idle_timeout
        Network.nw_quic_set_idle_timeout
        Network.nw_quic_get_initial_max_streams_bidirectional
        Network.nw_quic_set_initial_max_streams_bidirectional
        Network.nw_quic_get_initial_max_streams_unidirectional
        Network.nw_quic_set_initial_max_streams_unidirectional
        Network.nw_quic_get_initial_max_stream_data_bidirectional_local
        Network.nw_quic_set_initial_max_stream_data_bidirectional_local
        Network.nw_quic_get_initial_max_stream_data_bidirectional_remote
        Network.nw_quic_set_initial_max_stream_data_bidirectional_remote
        Network.nw_quic_get_initial_max_stream_data_unidirectional
        Network.nw_quic_set_initial_max_stream_data_unidirectional
        Network.nw_protocol_metadata_is_quic
        self.assertResultIsRetained(Network.nw_quic_copy_sec_protocol_metadata)
        Network.nw_quic_get_stream_application_error
        Network.nw_quic_set_stream_application_error
        Network.nw_quic_get_local_max_streams_bidirectional
        Network.nw_quic_set_local_max_streams_bidirectional
        Network.nw_quic_get_local_max_streams_unidirectional
        Network.nw_quic_set_local_max_streams_unidirectional
        Network.nw_quic_get_remote_max_streams_bidirectional
        Network.nw_quic_get_application_error
        Network.nw_quic_get_stream_id
        self.assertResultIsNullTerminated(Network.nw_quic_get_application_error_reason)
        self.assertArgIsNullTerminated(Network.nw_quic_set_application_error, 2)
        Network.nw_quic_get_keepalive_interval
        Network.nw_quic_set_keepalive_interval
        Network.nw_quic_get_remote_idle_timeout

    @min_os_level("13.0")
    def test_functions13_0(self):
        Network.nw_quic_get_stream_is_datagram
        Network.nw_quic_set_stream_is_datagram
        Network.nw_quic_get_max_datagram_frame_size
        Network.nw_quic_set_max_datagram_frame_size
        Network.nw_quic_get_stream_usable_datagram_frame_size



from PyObjCTools.TestSupport import TestCase

import Network


class TestContentContext(TestCase):
    def test_functions(self):
        self.assertResultIsRetained(Network.nw_content_context_create)
        self.assertArgIsIn(Network.nw_content_context_create, 0)
        self.assertArgIsNullTerminated(Network.nw_content_context_create, 0)

        self.assertResultIsNullTerminated(Network.nw_content_context_get_identifier)

        Network.nw_content_context_get_is_final
        Network.nw_content_context_set_is_final
        Network.nw_content_context_get_expiration_milliseconds
        Network.nw_content_context_set_expiration_milliseconds
        Network.nw_content_context_get_relative_priority
        Network.nw_content_context_set_relative_priority
        Network.nw_content_context_set_antecedent

        self.assertResultIsRetained(Network.nw_content_context_copy_antecedent)

        Network.nw_content_context_set_metadata_for_protocol

        self.assertResultIsRetained(Network.nw_content_context_copy_protocol_metadata)

        self.assertArgIsBlock(
            Network.nw_content_context_foreach_protocol_metadata, 1, b"v@@"
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network

nw_path_monitor_cancel_handler_t = b"v"
nw_path_monitor_update_handler_t = b"v@"


class TestPathMonitor(TestCase):
    def test_functions(self):
        self.assertResultIsRetained(Network.nw_path_monitor_create)

        self.assertResultIsRetained(Network.nw_path_monitor_create_with_type)

        self.assertArgIsBlock(
            Network.nw_path_monitor_set_cancel_handler,
            1,
            nw_path_monitor_cancel_handler_t,
        )

        self.assertArgIsBlock(
            Network.nw_path_monitor_set_update_handler,
            1,
            nw_path_monitor_update_handler_t,
        )

        Network.nw_path_monitor_set_queue
        Network.nw_path_monitor_start
        Network.nw_path_monitor_cancel

    @min_os_level("11.0")
    def test_functions11_0(self):
        Network.nw_path_monitor_prohibit_interface_type

    @min_os_level("13.0")
    def test_functions13_0(self):
        self.assertResultIsRetained(Network.nw_path_monitor_create_for_ethernet_channel)



from PyObjCTools.TestSupport import TestCase

import Network


class TestInterface(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_interface_type_other, 0)
        self.assertEqual(Network.nw_interface_type_wifi, 1)
        self.assertEqual(Network.nw_interface_type_cellular, 2)
        self.assertEqual(Network.nw_interface_type_wired, 3)
        self.assertEqual(Network.nw_interface_type_loopback, 4)

        self.assertEqual(Network.nw_interface_radio_type_unknown, 0)
        self.assertEqual(Network.nw_interface_radio_type_wifi_b, 1)
        self.assertEqual(Network.nw_interface_radio_type_wifi_a, 2)
        self.assertEqual(Network.nw_interface_radio_type_wifi_g, 3)
        self.assertEqual(Network.nw_interface_radio_type_wifi_n, 4)
        self.assertEqual(Network.nw_interface_radio_type_wifi_ac, 5)
        self.assertEqual(Network.nw_interface_radio_type_wifi_ax, 6)
        self.assertEqual(Network.nw_interface_radio_type_cell_lte, 0x80)
        self.assertEqual(Network.nw_interface_radio_type_cell_endc_sub6, 0x81)
        self.assertEqual(Network.nw_interface_radio_type_cell_endc_mmw, 0x82)
        self.assertEqual(Network.nw_interface_radio_type_cell_nr_sa_sub6, 0x83)
        self.assertEqual(Network.nw_interface_radio_type_cell_nr_sa_mmw, 0x84)
        self.assertEqual(Network.nw_interface_radio_type_cell_wcdma, 0x85)
        self.assertEqual(Network.nw_interface_radio_type_cell_gsm, 0x86)
        self.assertEqual(Network.nw_interface_radio_type_cell_cdma, 0x87)
        self.assertEqual(Network.nw_interface_radio_type_cell_evdo, 0x88)

    def test_functions(self):
        Network.nw_interface_get_type

        self.assertResultIsNullTerminated(Network.nw_interface_get_name)
        self.assertResultHasType(Network.nw_interface_get_name, b"^t")

        Network.nw_interface_get_index



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import Network


class TestAdvertiseDescriptor(TestCase):
    def test_functions(self):
        self.assertResultHasType(
            Network.nw_advertise_descriptor_create_bonjour_service, objc._C_ID
        )
        self.assertResultIsRetained(
            Network.nw_advertise_descriptor_create_bonjour_service
        )
        self.assertArgIsIn(Network.nw_advertise_descriptor_create_bonjour_service, 0)
        self.assertArgIsNullTerminated(
            Network.nw_advertise_descriptor_create_bonjour_service, 0
        )
        self.assertArgIsIn(Network.nw_advertise_descriptor_create_bonjour_service, 1)
        self.assertArgIsNullTerminated(
            Network.nw_advertise_descriptor_create_bonjour_service, 1
        )
        self.assertArgIsIn(Network.nw_advertise_descriptor_create_bonjour_service, 2)
        self.assertArgIsNullTerminated(
            Network.nw_advertise_descriptor_create_bonjour_service, 2
        )

        self.assertArgIsIn(Network.nw_advertise_descriptor_set_txt_record, 1)
        self.assertArgSizeInArg(Network.nw_advertise_descriptor_set_txt_record, 1, 2)

        self.assertArgHasType(
            Network.nw_advertise_descriptor_set_no_auto_rename, 1, objc._C_BOOL
        )
        self.assertResultHasType(
            Network.nw_advertise_descriptor_get_no_auto_rename, objc._C_BOOL
        )

    @min_os_level("10.15")
    def test_functions10_15(self):
        Network.nw_advertise_descriptor_set_txt_record_object

        self.assertResultIsRetained(
            Network.nw_advertise_descriptor_copy_txt_record_object
        )

    @min_os_level("11.0")
    def test_functions11_0(self):
        self.assertResultIsRetained(
            Network.nw_advertise_descriptor_copy_txt_record_object
        )

    @min_os_level("13.0")
    def test_functions13_0(self):
        self.assertResultIsRetained(
            Network.nw_advertise_descriptor_create_application_service
        )

        self.assertArgHasType(
            Network.nw_advertise_descriptor_create_application_service,
            0,
            b"n^" + objc._C_CHAR_AS_TEXT,
        )
        self.assertArgIsNullTerminated(
            Network.nw_advertise_descriptor_create_application_service, 0
        )

        self.assertResultHasType(
            Network.nw_advertise_descriptor_get_application_service_name,
            objc._C_PTR + objc._C_CHAR_AS_TEXT,
        )
        self.assertResultIsNullTerminated(
            Network.nw_advertise_descriptor_get_application_service_name
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network

nw_ws_pong_handler_t = b"v@"
nw_ws_subprotocol_enumerator_t = b"Bn^t"
nw_ws_additional_header_enumerator_t = b"Bn^tn^t"
nw_ws_client_request_handler_t = b"@@"


class TestWSOptions(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_ws_opcode_invalid, -1)
        self.assertEqual(Network.nw_ws_opcode_cont, 0x0)
        self.assertEqual(Network.nw_ws_opcode_text, 0x1)
        self.assertEqual(Network.nw_ws_opcode_binary, 0x2)
        self.assertEqual(Network.nw_ws_opcode_close, 0x8)
        self.assertEqual(Network.nw_ws_opcode_ping, 0x9)
        self.assertEqual(Network.nw_ws_opcode_pong, 0xA)

        self.assertEqual(Network.nw_ws_close_code_normal_closure, 1000)
        self.assertEqual(Network.nw_ws_close_code_going_away, 1001)
        self.assertEqual(Network.nw_ws_close_code_protocol_error, 1002)
        self.assertEqual(Network.nw_ws_close_code_unsupported_data, 1003)
        self.assertEqual(Network.nw_ws_close_code_no_status_received, 1005)
        self.assertEqual(Network.nw_ws_close_code_abnormal_closure, 1006)
        self.assertEqual(Network.nw_ws_close_code_invalid_frame_payload_data, 1007)
        self.assertEqual(Network.nw_ws_close_code_policy_violation, 1008)
        self.assertEqual(Network.nw_ws_close_code_message_too_big, 1009)
        self.assertEqual(Network.nw_ws_close_code_mandatory_extension, 1010)
        self.assertEqual(Network.nw_ws_close_code_internal_server_error, 1011)
        self.assertEqual(Network.nw_ws_close_code_tls_handshake, 1015)

        self.assertEqual(Network.nw_ws_version_13, 1)

        self.assertEqual(Network.nw_ws_response_status_invalid, 0)
        self.assertEqual(Network.nw_ws_response_status_accept, 1)
        self.assertEqual(Network.nw_ws_response_status_reject, 2)

    @min_os_level("10.15")
    def test_functions10_15(self):
        self.assertResultIsRetained(Network.nw_protocol_copy_ws_definition)
        self.assertResultIsRetained(Network.nw_ws_create_options)

        Network.nw_ws_options_add_additional_header
        Network.nw_ws_options_add_subprotocol
        Network.nw_ws_options_set_auto_reply_ping
        Network.nw_ws_options_set_skip_handshake
        Network.nw_ws_options_set_maximum_message_size
        Network.nw_protocol_metadata_is_ws

        self.assertResultIsRetained(Network.nw_ws_create_metadata)

        Network.nw_ws_metadata_get_opcode
        Network.nw_ws_metadata_set_close_code
        Network.nw_ws_metadata_get_close_code

        self.assertArgIsBlock(
            Network.nw_ws_metadata_set_pong_handler, 2, nw_ws_pong_handler_t
        )
        self.assertArgIsBlock(
            Network.nw_ws_request_enumerate_subprotocols,
            1,
            nw_ws_subprotocol_enumerator_t,
        )
        self.assertArgIsBlock(
            Network.nw_ws_request_enumerate_additional_headers,
            1,
            nw_ws_additional_header_enumerator_t,
        )

        self.assertResultIsRetained(Network.nw_ws_response_create)
        self.assertArgHasType(Network.nw_ws_response_create, 1, b"n^t")
        self.assertArgSizeInArg(Network.nw_ws_response_create, 1, 2)

        Network.nw_ws_response_get_status

        self.assertResultIsNullTerminated(
            Network.nw_ws_response_get_selected_subprotocol
        )
        self.assertResultHasType(Network.nw_ws_response_get_selected_subprotocol, b"^t")

        self.assertArgHasType(Network.nw_ws_response_add_additional_header, 1, b"n^t")
        self.assertArgIsNullTerminated(Network.nw_ws_response_add_additional_header, 1)
        self.assertArgHasType(Network.nw_ws_response_add_additional_header, 2, b"n^t")
        self.assertArgIsNullTerminated(Network.nw_ws_response_add_additional_header, 2)

        self.assertResultIsRetained(Network.nw_ws_metadata_copy_server_response)

        self.assertArgIsBlock(
            Network.nw_ws_response_enumerate_additional_headers,
            1,
            nw_ws_additional_header_enumerator_t,
        )
        self.assertArgIsBlock(
            Network.nw_ws_options_set_client_request_handler,
            2,
            nw_ws_client_request_handler_t,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network


class TestConnectionGroup(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_connection_group_state_invalid, 0)
        self.assertEqual(Network.nw_connection_group_state_waiting, 1)
        self.assertEqual(Network.nw_connection_group_state_ready, 2)
        self.assertEqual(Network.nw_connection_group_state_failed, 3)
        self.assertEqual(Network.nw_connection_group_state_cancelled, 4)

    @min_os_level("11.0")
    def test_functions11_0(self):
        self.assertResultIsRetained(Network.nw_connection_group_create)
        self.assertResultIsRetained(Network.nw_connection_group_copy_descriptor)
        self.assertResultIsRetained(Network.nw_connection_group_copy_parameters)

        Network.nw_connection_group_set_queue

        nw_connection_group_state_changed_handler_t = b"vi@"

        self.assertArgIsBlock(
            Network.nw_connection_group_set_state_changed_handler,
            1,
            nw_connection_group_state_changed_handler_t,
        )

        nw_connection_group_receive_handler_t = b"v@@B"

        self.assertArgIsBlock(
            Network.nw_connection_group_set_receive_handler,
            3,
            nw_connection_group_receive_handler_t,
        )

        Network.nw_connection_group_start
        Network.nw_connection_group_cancel

        self.assertResultIsRetained(
            Network.nw_connection_group_copy_remote_endpoint_for_message
        )
        self.assertResultIsRetained(
            Network.nw_connection_group_copy_local_endpoint_for_message
        )
        self.assertResultIsRetained(
            Network.nw_connection_group_copy_local_endpoint_for_message
        )

        Network.nw_connection_group_reply

        self.assertResultIsRetained(
            Network.nw_connection_group_extract_connection_for_message
        )

        nw_connection_group_send_completion_t = b"v@"

        self.assertArgIsBlock(
            Network.nw_connection_group_send_message,
            4,
            nw_connection_group_send_completion_t,
        )

    @min_os_level("12.0")
    def test_functions12_0(self):
        self.assertResultIsRetained(
            Network.nw_connection_group_copy_protocol_metadata_for_message
        )
        self.assertResultIsRetained(
            Network.nw_connection_group_extract_connection_for_message
        )
        self.assertResultIsRetained(Network.nw_connection_group_extract_connection)
        Network.nw_connection_group_reinsert_extracted_connection

        nw_connection_group_new_connection_handler_t = b"v@"

        self.assertArgIsBlock(
            Network.nw_connection_group_set_new_connection_handler,
            1,
            nw_connection_group_new_connection_handler_t,
        )

        self.assertResultIsRetained(Network.nw_connection_group_copy_protocol_metadata)



from PyObjCTools.TestSupport import TestCase

import Network


class TestError(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_error_domain_invalid, 0)
        self.assertEqual(Network.nw_error_domain_posix, 1)
        self.assertEqual(Network.nw_error_domain_dns, 2)
        self.assertEqual(Network.nw_error_domain_tls, 3)

        self.assertIsInstance(Network.kNWErrorDomainPOSIX, str)
        self.assertIsInstance(Network.kNWErrorDomainDNS, str)
        self.assertIsInstance(Network.kNWErrorDomainTLS, str)

    def test_functions(self):
        Network.nw_error_get_error_domain
        Network.nw_error_get_error_code

        self.assertResultIsCFRetained(Network.nw_error_copy_cf_error)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc

import Network

nw_ethernet_channel_state_changed_handler_t = b"v@@"
nw_ethernet_channel_receive_handler_t = b"v@" + objc._C_USHT + b"n[6t]n[6t]"
nw_ethernet_channel_send_completion_t = b"v@"


class TestEtherChannel(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_ethernet_channel_state_invalid, 0)
        self.assertEqual(Network.nw_ethernet_channel_state_waiting, 1)
        self.assertEqual(Network.nw_ethernet_channel_state_preparing, 2)
        self.assertEqual(Network.nw_ethernet_channel_state_ready, 3)
        self.assertEqual(Network.nw_ethernet_channel_state_failed, 4)
        self.assertEqual(Network.nw_ethernet_channel_state_cancelled, 5)

    @min_os_level("10.15")
    def test_functions10_15(self):
        self.assertResultIsRetained(Network.nw_ethernet_channel_create)

        self.assertArgIsBlock(
            Network.nw_ethernet_channel_set_state_changed_handler,
            1,
            nw_ethernet_channel_state_changed_handler_t,
        )

        Network.nw_ethernet_channel_set_queue
        Network.nw_ethernet_channel_start
        Network.nw_ethernet_channel_cancel

        self.assertArgIsBlock(
            Network.nw_ethernet_channel_set_receive_handler,
            1,
            nw_ethernet_channel_receive_handler_t,
        )
        self.assertArgIsBlock(
            Network.nw_ethernet_channel_send, 4, nw_ethernet_channel_send_completion_t
        )

    @min_os_level("13.0")
    def test_functions13_0(self):
        self.assertResultIsRetained(Network.nw_ethernet_channel_create_with_parameters)

        Network.nw_ethernet_channel_get_maximum_payload_size



from PyObjCTools.TestSupport import TestCase, min_os_level

import Network

nw_txt_record_access_key_t = b"Bn^t@n^vL"
nw_txt_record_access_bytes_t = b"Bn^vL"
nw_txt_record_applier_t = b"Bn^t@n^vL"


class TestTxtRecord(TestCase):
    def test_constants(self):
        self.assertEqual(Network.nw_txt_record_find_key_invalid, 0)
        self.assertEqual(Network.nw_txt_record_find_key_not_present, 1)
        self.assertEqual(Network.nw_txt_record_find_key_no_value, 2)
        self.assertEqual(Network.nw_txt_record_find_key_empty_value, 3)
        self.assertEqual(Network.nw_txt_record_find_key_non_empty_value, 4)

    @min_os_level("10.15")
    def test_functions10_15(self):
        self.assertResultIsRetained(Network.nw_txt_record_create_with_bytes)
        self.assertArgHasType(Network.nw_txt_record_create_with_bytes, 0, b"n^v")
        self.assertArgSizeInArg(Network.nw_txt_record_create_with_bytes, 0, 1)

        self.assertResultIsRetained(Network.nw_txt_record_create_dictionary)
        self.assertResultIsRetained(Network.nw_txt_record_copy)

        self.assertArgHasType(Network.nw_txt_record_find_key, 1, b"n^t")
        self.assertArgIsNullTerminated(Network.nw_txt_record_find_key, 1)

        self.assertArgIsIn(Network.nw_txt_record_access_key, 1)
        self.assertArgIsNullTerminated(Network.nw_txt_record_access_key, 1)
        self.assertArgIsBlock(
            Network.nw_txt_record_access_key, 2, nw_txt_record_access_key_t
        )

        self.assertArgIsIn(Network.nw_txt_record_set_key, 1)
        self.assertArgIsNullTerminated(Network.nw_txt_record_set_key, 1)
        self.assertArgHasType(Network.nw_txt_record_set_key, 2, b"n^v")
        self.assertArgSizeInArg(Network.nw_txt_record_set_key, 2, 3)

        self.assertArgIsIn(Network.nw_txt_record_remove_key, 1)
        self.assertArgIsNullTerminated(Network.nw_txt_record_remove_key, 1)

        Network.nw_txt_record_get_key_count

        self.assertArgIsBlock(
            Network.nw_txt_record_access_bytes, 1, nw_txt_record_access_bytes_t
        )

        self.assertArgIsBlock(Network.nw_txt_record_apply, 1, nw_txt_record_applier_t)

        Network.nw_txt_record_is_equal
        Network.nw_txt_record_is_dictionary
